'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');

const apply = new Schema({
  user_id: { type: String, required: true, maxLength: 200 }, // 用户id
  user_name: { type: String, required: true, maxLength: 200 }, // 用户名称
  buyer: { type: String, required: true, maxLength: 1 }, // 买家/卖家 0/1
  goodsList: [ Object ],
  contact: { type: String, required: true, maxLength: 200 }, // 联系人
  contact_tel: { type: String, required: true, maxLength: 200 }, // 联系人电话
  email: { type: String, maxLength: 200 }, // 邮箱
  company: { type: String, maxLength: 200 }, // 单位名称
  apply_time: { type: String, maxLength: 200 }, // 申请时间
  role: { type: String, maxLength: 200 }, // 申请人类型
  status: { type: String, default: 0, maxLength: 1 }, // 申请状态 (0未审核;1已通过;2已拒绝)
});
apply.index({ id: 1 });
apply.index({ userid: 1 });
const vipuser = new Schema({
  uid: { type: String, required: false, maxLength: 200 }, // 用户id
  vipname: { type: String, required: false, maxLength: 200 }, // 用户名称
  vipphone: { type: String, required: false, maxLength: 200 }, // 联系人手机
  role: { type: String, required: false, maxLength: 200 }, // 申请人类型
  company: { type: String, required: false, maxLength: 500 }, // 单位名称
  email: { type: String, required: false, maxLength: 20 }, // 单位名称
  content: { type: String, required: false }, // 单位名称
});
vipuser.index({ id: 1 });
const Dock = {
  title: { type: String, required: true, maxLength: 200 }, // 对接会标题
  desc: { type: String, maxLength: 1000 }, // 简介
  status: { type: String, default: '0', maxLength: 1 }, // 状态:0准备中;1已开始;2已结束
  start_time: { type: String, required: true, maxLength: 200 }, // 开始时间
  end_time: { type: String, required: true, maxLength: 200 }, // 结束时间
  join_end: { type: String, required: true, maxLength: 200 }, // 报名截止时间
  apply: { type: [ apply ], default: [] },
  is_allowed: { type: String, default: '0', maxLength: 1 }, // 0未审核;1已允许;2已拒绝
  reason: { type: String, required: false, maxLength: 200 }, // 拒绝理由
  user_id: { type: String, required: true, maxLength: 200 }, // 申请用户
  province: { type: String, required: false }, // 省
  file_path: { type: String, required: false }, // 视频路径
  place: { type: String, required: false }, // 位置
  roomname: { type: String, required: false }, // 房间号
  uid: { type: String, required: false, maxLength: 200 }, // 所属用户
  adminuser: { type: String, required: false, maxLength: 200 }, // 所属用户姓名
  phone: { type: String, required: false, maxLength: 200 }, // 所属电话
  vipuser: { type: [ vipuser ], default: [] }, // vip用户
};
const schema = new Schema(Dock, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.plugin(metaPlugin);

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('dock', schema, 'dock');
};
